package ru.ibs.tests;

import io.cucumber.java.ru.*;
import static org.junit.Assert.*;

import io.cucumber.java.After;
import org.openqa.selenium.By;
import ru.ibs.framework.managers.DriverManager;
import ru.ibs.tests.*;

public class BusinessTripSteps {

    private final LoginPage loginPage = new LoginPage(DriverManager.getDriverManager().getDriver());
    private DashboardPage dashboardPage;
    private BusinessTripPage businessTripPage;

    @Дано("Открываем страницу логина")
    public void openLoginPage() {
        DriverManager.getDriverManager().getDriver().get("http://training.appline.ru/user/login");
    }

    @И("Вводим логин {string} и пароль {string}")
    public void login(String username, String password) {
        dashboardPage = loginPage.login(username, password);
    }

    @И("Проверяем, что панель быстрого запуска загружена")
    public void dashboardLoaded() {
        assertTrue("Dashboard not loaded", dashboardPage.isDashboardLoaded());
    }

    @И("Переходим в раздел {string}")
    public void goToBusinessTrip(String name) {
        businessTripPage = dashboardPage.goToBusinessTrip();
    }

    @И("Проверяем, что страница {string} загружена")
    public void tripsPageLoaded(String title) {
        assertTrue("Trips page not loaded", businessTripPage.isTripsPageLoaded());
    }

    @И("Нажимаем на кнопку создания новой командировки")
    public void openCreateTripForm() {
        businessTripPage.openCreateTripForm();
    }

    @И("Выбираем подразделение {string}")
    public void selectDepartment(String department) {
        businessTripPage.selectDepartment(department);
    }

    @И("Выбираем организацию {string}")
    public void selectOrganization(String organization) {
        businessTripPage.selectOrganization(organization);
    }

    @И("Устанавливаем чекбокс {string} в положение {string}")
    public void setCheckbox(String checkboxName, String value) {
        boolean checked = Boolean.parseBoolean(value);
        businessTripPage.setTicketsCheckbox(checked);
    }

    @И("Заполняем поле {string} значением {string}")
    public void fillCityOrDate(String field, String value) {
        if (field.equalsIgnoreCase("Город")) {
            businessTripPage.fillCity(value);
        } else if (field.equalsIgnoreCase("Дата отправления")) {
            businessTripPage.fillDate(By.xpath("//input[@placeholder='Укажите дату' and contains(@id, 'departureDatePlan')]"), value);
        } else if (field.equalsIgnoreCase("Дата возвращения")) {
            businessTripPage.fillDate(By.xpath("//input[@placeholder='Укажите дату' and contains(@id, 'returnDatePlan')]"), value);
        }
    }

    @И("Нажимаем кнопку {string}")
    public void clickButton(String buttonName) {
        if (buttonName.equals("Сохранить и закрыть")) {
            businessTripPage.saveAndClose();
        }
    }

    @Тогда("Проверяем, что отображается ошибка {string}")
    public void checkError(String errorText) {
        assertTrue("Expected validation error not shown",
                businessTripPage.isErrorDisplayed(errorText));
    }

    @After
    public void tearDown() {
        DriverManager.getDriverManager().quitDriver();
    }
}
